pygeodesy.css.CassiniSoldner

Package pygeodesy :: Module css :: Class CassiniSoldner |
[frames] | no frames]

# Class CassiniSoldner

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
                      CassiniSoldner

Cassini-Soldner projection, a Python version of Karney's C++ class CassiniSoldner.

Instance Methods
__init__(self, lat0, lon0, datum=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Tran`...`, **name) New CassiniSoldner projection. |
forward(self, lat, lon, **name) Convert an (ellipsoidal) geodetic location to Cassini-Soldner easting and northing. |
forward4(self, lat, lon, **name) Convert an (ellipsoidal) geodetic location to Cassini-Soldner easting and northing. |
forward6(self, lat, lon, **name) Convert an (ellipsoidal) geodetic location to Cassini-Soldner easting and northing. |
reset(self, lat0, lon0) Set or reset the center point of this Cassini-Soldner projection. |
reverse(self, easting, northing, LatLon=None, **name_LatLon_kwds) Convert a Cassini-Soldner location to (ellipsoidal) geodetic lat- and longitude. |
reverse4(self, easting, northing, **name) Convert a Cassini-Soldner location to (ellipsoidal) geodetic lat- and longitude. |
toLatLon(self, easting, northing, LatLon=None, **name_LatLon_kwds) Convert a Cassini-Soldner location to (ellipsoidal) geodetic lat- and longitude. |
toRepr(self, prec=6, **unused) Return a string representation of this projection. |
toStr(self, prec=6, sep=' ', **unused) Return a string representation of this projection. |
Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| datum Get the datum (Datum).
| equatoradius Get the ellipsoid's equatorial radius, semi-axis (`meter`).
| a Get the ellipsoid's equatorial radius, semi-axis (`meter`).
| flattening Get the ellipsoid's flattening (`scalar`).
| f Get the ellipsoid's flattening (`scalar`).
| geodesic Get this projection's wrapped geodesic.Geodesic from Karney's geographiclib package if installed, otherwise an exact GeodesicExact instance.
| isExact Return `True` if this projection's geodesic is GeodesicExact.
| lat0 Get the center latitude (`degrees90`).
| latlon0 Get the center lat- and longitude (LatLon2Tuple`(lat, lon)`) in (`degrees90`, (`degrees180`).
| lon0 Get the center longitude (`degrees180`).
| majoradius DEPRECATED, use property `equatoradius`.
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, lat0, lon0, datum=Datum(name='WGS84', ellipsoid=Ellipsoids.WGS84, transform=Tran`...`, **name) (Constructor) |
New CassiniSoldner projection. Arguments: `lat0` - Latitude of center point (`degrees90`). `lon0` - Longitude of center point (`degrees180`). `datum` - Optional datum or ellipsoid (Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple). `name` - Optional `name=NN` (`str`). Raises: `CSSError` - Invalid `lat` or `lon`. Overrides: object.__init__

### forward (self, lat, lon, **name) |
Convert an (ellipsoidal) geodetic location to Cassini-Soldner easting and northing. Arguments: `lat` - Latitude of the location (`degrees90`). `lon` - Longitude of the location (`degrees180`). `name` - Optional `name=NN` inlieu of this projection's name (`str`). Returns: An EasNor2Tuple`(easting, northing)`. Raises: `CSSError` - Invalid `lat` or `lon`. See Also: Methods CassiniSoldner.forward4, CassiniSoldner.reverse and CassiniSoldner.reverse4.

### forward4 (self, lat, lon, **name) |
Convert an (ellipsoidal) geodetic location to Cassini-Soldner easting and northing. Arguments: `lat` - Latitude of the location (`degrees90`). `lon` - Longitude of the location (`degrees180`). `name` - Optional `name`=NN inlieu of this projection's name (`str`). Returns: An EasNorAziRk4Tuple`(easting, northing, azimuth, reciprocal)`. Raises: `CSSError` - Invalid `lat` or `lon`. See Also: Method CassiniSoldner.forward, CassiniSoldner.forward6, CassiniSoldner.reverse and CassiniSoldner.reverse4.

### forward6 (self, lat, lon, **name) |
Convert an (ellipsoidal) geodetic location to Cassini-Soldner easting and northing. Arguments: `lat` - Latitude of the location (`degrees90`). `lon` - Longitude of the location (`degrees180`). `name` - Optional `name`=NN inlieu of this projection's name (`str`). Returns: An EasNorAziRkEqu6Tuple`(easting, northing, azimuth, reciprocal, equatorarc, equatorazimuth)`. Raises: `CSSError` - Invalid `lat` or `lon`. See Also: Method CassiniSoldner.forward, CassiniSoldner.forward4, CassiniSoldner.reverse and CassiniSoldner.reverse4.

### reset (self, lat0, lon0) |
Set or reset the center point of this Cassini-Soldner projection. Arguments: `lat0` - Center point latitude (`degrees90`). `lon0` - Center point longitude (`degrees180`). Raises: `CSSError` - Invalid `lat0` or `lon0`.

### reverse (self, easting, northing, LatLon=None, **name_LatLon_kwds) |
Convert a Cassini-Soldner location to (ellipsoidal) geodetic lat- and longitude. Arguments: `easting` - Easting of the location (`meter`). `northing` - Northing of the location (`meter`). `LatLon` - Optional, ellipsoidal class to return the geodetic location as (`LatLon`) or `None`. `name_LatLon_kwds` - Optional name `name=NN` (`str`) and optionally, additional `LatLon` keyword arguments, ignored if `LatLon is None`. Returns: Geodetic location `LatLon` or if `LatLon is None`, a LatLon2Tuple`(lat, lon)`. Raises: `CSSError` - Ellipsoidal mismatch of `LatLon` and this projection. `TypeError` - Invalid `LatLon` or `LatLon_kwds`. See Also: Method CassiniSoldner.reverse4, CassiniSoldner.forward. CassiniSoldner.forward4 and CassiniSoldner.forward6.

### reverse4 (self, easting, northing, **name) |
Convert a Cassini-Soldner location to (ellipsoidal) geodetic lat- and longitude. Arguments: `easting` - Easting of the location (`meter`). `northing` - Northing of the location (`meter`). `name` - Optional `name`=NN inlieu of this projection's name (`str`). Returns: A LatLonAziRk4Tuple`(lat, lon, azimuth, reciprocal)`. See Also: Method CassiniSoldner.reverse, CassiniSoldner.forward and CassiniSoldner.forward4.

### toLatLon (self, easting, northing, LatLon=None, **name_LatLon_kwds) |
Convert a Cassini-Soldner location to (ellipsoidal) geodetic lat- and longitude. Arguments: `easting` - Easting of the location (`meter`). `northing` - Northing of the location (`meter`). `LatLon` - Optional, ellipsoidal class to return the geodetic location as (`LatLon`) or `None`. `name_LatLon_kwds` - Optional name `name=NN` (`str`) and optionally, additional `LatLon` keyword arguments, ignored if `LatLon is None`. Returns: Geodetic location `LatLon` or if `LatLon is None`, a LatLon2Tuple`(lat, lon)`. Raises: `CSSError` - Ellipsoidal mismatch of `LatLon` and this projection. `TypeError` - Invalid `LatLon` or `LatLon_kwds`. See Also: Method CassiniSoldner.reverse4, CassiniSoldner.forward. CassiniSoldner.forward4 and CassiniSoldner.forward6.

### toRepr (self, prec=6, **unused) |
Return a string representation of this projection. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). Returns: This projection as `"<classname>(lat0, lon0, ...)"` (`str`). Overrides: named._Named.toRepr

### toStr (self, prec=6, sep=' ', **unused) |
Return a string representation of this projection. Arguments: `prec` - Number of (decimal) digits, unstripped (`int`). `sep` - Separator to join (`str`). Returns: This projection as `"lat0 lon0"` (`str`). Overrides: named._Named.toStr

Property Details

### datum Get the datum (Datum). Get method: datum(self) - Get the datum (Datum). Set method: datum(self, datum) - Set the datum or ellipsoid (Datum, Ellipsoid, Ellipsoid2 or a_f2Tuple) or `None` for the default. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### equatoradius Get the ellipsoid's equatorial radius, semi-axis (`meter`). Get method: equatoradius(self) - Get the ellipsoid's equatorial radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### a Get the ellipsoid's equatorial radius, semi-axis (`meter`). Get method: equatoradius(self) - Get the ellipsoid's equatorial radius, semi-axis (`meter`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### flattening Get the ellipsoid's flattening (`scalar`). Get method: flattening(self) - Get the ellipsoid's flattening (`scalar`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### f Get the ellipsoid's flattening (`scalar`). Get method: flattening(self) - Get the ellipsoid's flattening (`scalar`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### geodesic Get this projection's wrapped geodesic.Geodesic from Karney's geographiclib package if installed, otherwise an exact GeodesicExact instance. Get method: geodesic(self) - Get this projection's wrapped geodesic.Geodesic from Karney's geographiclib package if installed, otherwise an exact GeodesicExact instance. Set method: geodesic(self, exact) - Set this projection's geodesic (`bool`) to GeodesicExact or wrapped Karney's or `None` for the default. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isExact Return `True` if this projection's geodesic is GeodesicExact. Get method: isExact(self) - Return `True` if this projection's geodesic is GeodesicExact. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### lat0 Get the center latitude (`degrees90`). Get method: lat0(self) - Get the center latitude (`degrees90`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### latlon0 Get the center lat- and longitude (LatLon2Tuple`(lat, lon)`) in (`degrees90`, (`degrees180`). Get method: latlon0(self) - Get the center lat- and longitude (LatLon2Tuple`(lat, lon)`) in (`degrees90`, (`degrees180`). Set method: latlon0(self, latlon0) - Set the center lat- and longitude (ellipsoidal `LatLon`, LatLon2Tuple, LatLon4Tuple or a `tuple` or `list` with the `lat`- and `lon`gitude in `degrees`).

### lon0 Get the center longitude (`degrees180`). Get method: lon0(self) - Get the center longitude (`degrees180`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### majoradius DEPRECATED, use property `equatoradius`. Get method: majoradius(self) - DEPRECATED, use property `equatoradius`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.